@@ -28,6 +28,7 @@ class SaleCreditLimitTestCase(ModuleTestCase):
         PaymentTerm = pool.get('account.invoice.payment_term')
         Configuration = pool.get('account.configuration')
         FiscalYear = pool.get('account.fiscalyear')
+        Invoice = pool.get('account.invoice')
 
         company = create_company()
         with set_company(company):
@@ -75,7 +76,7 @@ class SaleCreditLimitTestCase(ModuleTestCase):
                             ],
                         }])
             config = Configuration(1)
-            config.default_product_account_revenue = revenue
+            config.default_category_account_revenue = revenue
             config.save()
             sale, = Sale.create([{
                         'party': party.id,
@@ -114,6 +115,14 @@ class SaleCreditLimitTestCase(ModuleTestCase):
             # process should still work as sale is already processing
             Sale.process([sale])
 
+            # Increase quantity invoiced does not change the credit amount
+            invoice, = sale.invoices
+            invoice_line, = invoice.lines
+            invoice_line.quantity += 1
+            invoice_line.save()
+            Invoice.post([invoice])
+            self.assertEqual(party.credit_amount, Decimal('150'))
+
 
 def suite():
     suite = trytond.tests.test_tryton.suite()
